Class: PgAnyWhere::Railtie

Inherits:
Rails::Railtie
  • Object
show all
Defined in:
lib/pg_any_where/railtie.rb

Overview

Rails Railtie — automatically calls PgAnyWhere.patch! during the after_initialize phase so the patch lands after the database connection is established and the Arel visitor class is fully loaded.